import { DateTime } from "luxon";
import { useQuery } from "react-query";
import { fetchUserInfo } from "../../api";
import { Modal } from "../Modal";
import { useState } from "preact/hooks";

type DisplayProps = {
    timezone: string;
};

const TimezoneDisplay = ({ timezone }: DisplayProps) => {
    const now = DateTime.now().setZone(timezone);

    const hour = now.hour;
    const minute = now.minute;

    return (
        <>
            <strong>
                <span class="set-timezone">{timezone}</span>
            </strong>{" "}
            (
            <span class="set-time">
                {hour}:{minute}
            </span>
            )
        </>
    );
};

export const TimezonePicker = () => {
    const [modalOpen, setModalOpen] = useState(false);

    return (
        <>
            <a
                class="show-modal"
                data-modal="chooseTimezoneModal"
                onClick={() => {
                    setModalOpen(true);
                }}
            >
                <span class="icon">
                    <i class="fas fa-map-marked"></i>
                </span>{" "}
                Timezone
            </a>
            {modalOpen && <TimezoneModal setModalOpen={setModalOpen} />}
        </>
    );
};

const TimezoneModal = ({ setModalOpen }) => {
    const browserTimezone = DateTime.now().zone.name;

    const { isLoading, isError, data } = useQuery(fetchUserInfo());

    return (
        <Modal title={"Timezone"} setModalOpen={setModalOpen}>
            <p>
                Your configured timezone is:{" "}
                <TimezoneDisplay timezone={browserTimezone}></TimezoneDisplay>
                <br></br>
                <br></br>
                Your browser timezone is:{" "}
                <TimezoneDisplay timezone={browserTimezone}></TimezoneDisplay>
                <br></br>
                {!isError && (
                    <>
                        Your bot timezone is:{" "}
                        {isLoading ? (
                            <i className="fas fa-cog fa-spin"></i>
                        ) : (
                            <TimezoneDisplay timezone={data.timezone || "UTC"}></TimezoneDisplay>
                        )}
                    </>
                )}
            </p>
            <br></br>
            <div class="has-text-centered">
                <button class="button is-success close-modal" id="set-browser-timezone">
                    <span>Use Browser Timezone</span>{" "}
                    <span class="icon">
                        <i class="fab fa-firefox-browser"></i>
                    </span>
                </button>
                <button class="button is-link close-modal" id="set-bot-timezone">
                    <span>Use Bot Timezone</span>{" "}
                    <span class="icon">
                        <i class="fab fa-discord"></i>
                    </span>
                </button>
                <button class="button is-warning close-modal" id="update-bot-timezone">
                    Set Bot Timezone
                </button>
            </div>
        </Modal>
    );
};
